==> haskell-tasty-lua-0.2.0.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-EQPtgvM4YJGEA4FbJO9qcc
key: tasty-lua-0.2.0.1-EQPtgvM4YJGEA4FbJO9qcc
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: bfc3c5696f19dd7925ba4043ab68e833
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-EQPtgvM4YJGEA4FbJO9qcc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    hslua-1.0.3.2-Fs6khi7Cq5y8CwYMQ4vQZm
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-0.2.0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-186gxCDpbGBKRhEh7uJtiO
key: tasty-lua-0.2.0.1-186gxCDpbGBKRhEh7uJtiO
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: 659045909e400f4317586caa6ffc07b5
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-186gxCDpbGBKRhEh7uJtiO
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    hslua-1.0.3.2-9XdBa9n2D5gDaNt3JZ5IEq
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
